# nonebot-plugin-abstract

适用于 Nonebot2 的语句抽象化插件

### 目前已实现功能
- [x] 语句抽象话。

### 未来要实现的功能
- [ ] 分好抽象等级，例如基本抽象和深度抽象。~~怕抽象的语句过于抽象了。~~


### 安装

- 使用 nb-cli

```
nb plugin install nonebot_plugin_abstract
```

- 使用 pip

```
pip install nonebot_plugin_abstract
```


### 使用
```
抽象 [要抽象的语句]
```


### 示例

<div align="left">
  <img src="https://s2.loli.net/2022/03/25/qdiuRKBILSJ1NxV.jpg" width="400" />
</div>


### 特别感谢

- [THUzhangga/NMSL](https://github.com/THUzhangga/NMSL) Abstraction your words——never mind the scandal and liber
